@@ -1,16 +1,8 @@
 /*
- * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2008,2009,2010,2011 Rolf Eike Beer <kde@opensource.sf-tec.de>
- */
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-FileCopyrightText: 2002 Jean-Baptiste Mardelle <bj@altern.org>
+    SPDX-FileCopyrightText: 2008, 2009, 2010, 2011 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef _KGPGEXTERNALACTIONS_H
 #define _KGPGEXTERNALACTIONS_H
@@ -41,7 +33,7 @@ class KGpgExternalActions : public QObject
 
 public:
 	KGpgExternalActions(KeysManager *parent, KGpgItemModel *model);
-	~KGpgExternalActions();
+	~KGpgExternalActions() override;
 
 	void showDroppedFile(const QUrl &file);
 	void verifyFile(QUrl url);
