@@ -6,7 +6,7 @@
 
 class KGpgEncryptTest : public QObject {
 	Q_OBJECT
-private slots:
+private Q_SLOTS:
 	void init();
 	void testAsciiArmoredEncryption();
 	void testHideKeyIdEncryption();
