@@ -7,7 +7,7 @@
 class KGpgVerifyTest: public QObject
 {
 	Q_OBJECT
-private slots:
+private Q_SLOTS:
 	void init();
 	void testVerifySignedText();
 	void testVerifySignedFile();
